<?php

namespace TelegramApi\Types;

class ChatMember implements TypeInterface
{
	/** @var User Information about the user */
	public User $user;

	/** @var string The member's status in the chat. Can be “creator”, “administrator”, “member”, “restricted”, “left” or “kicked” */
	public string $status;

	/** @var string|null Optional. Owner and administrators only. Custom title for this user */
	public ?string $customTitle = null;

	/** @var bool|null Optional. Owner and administrators only. True, if the user's presence in the chat is hidden */
	public ?bool $isAnonymous = null;

	/** @var bool|null Optional. Administrators only. True, if the bot is allowed to edit administrator privileges of that user */
	public ?bool $canBeEdited = null;

	/** @var bool|null Optional. Administrators only. True, if the administrator can access the chat event log, chat statistics, message statistics in channels, see channel members, see anonymous administrators in supergroups and ignore slow mode. Implied by any other administrator privilege */
	public ?bool $canManageChat = null;

	/** @var bool|null Optional. Administrators only. True, if the administrator can post in the channel; channels only */
	public ?bool $canPostMessages = null;

	/** @var bool|null Optional. Administrators only. True, if the administrator can edit messages of other users and can pin messages; channels only */
	public ?bool $canEditMessages = null;

	/** @var bool|null Optional. Administrators only. True, if the administrator can delete messages of other users */
	public ?bool $canDeleteMessages = null;

	/** @var bool|null Optional. Administrators only. True, if the administrator can manage voice chats */
	public ?bool $canManageVoiceChats = null;

	/** @var bool|null Optional. Administrators only. True, if the administrator can restrict, ban or unban chat members */
	public ?bool $canRestrictMembers = null;

	/** @var bool|null Optional. Administrators only. True, if the administrator can add new administrators with a subset of their own privileges or demote administrators that he has promoted, directly or indirectly (promoted by administrators that were appointed by the user) */
	public ?bool $canPromoteMembers = null;

	/** @var bool|null Optional. Administrators and restricted only. True, if the user is allowed to change the chat title, photo and other settings */
	public ?bool $canChangeInfo = null;

	/** @var bool|null Optional. Administrators and restricted only. True, if the user is allowed to invite new users to the chat */
	public ?bool $canInviteUsers = null;

	/** @var bool|null Optional. Administrators and restricted only. True, if the user is allowed to pin messages; groups and supergroups only */
	public ?bool $canPinMessages = null;

	/** @var bool|null Optional. Restricted only. True, if the user is a member of the chat at the moment of the request */
	public ?bool $isMember = null;

	/** @var bool|null Optional. Restricted only. True, if the user is allowed to send text messages, contacts, locations and venues */
	public ?bool $canSendMessages = null;

	/** @var bool|null Optional. Restricted only. True, if the user is allowed to send audios, documents, photos, videos, video notes and voice notes */
	public ?bool $canSendMediaMessages = null;

	/** @var bool|null Optional. Restricted only. True, if the user is allowed to send polls */
	public ?bool $canSendPolls = null;

	/** @var bool|null Optional. Restricted only. True, if the user is allowed to send animations, games, stickers and use inline bots */
	public ?bool $canSendOtherMessages = null;

	/** @var bool|null Optional. Restricted only. True, if the user is allowed to add web page previews to their messages */
	public ?bool $canAddWebPagePreviews = null;

	/** @var int|null Optional. Restricted and kicked only. Date when restrictions will be lifted for this user; unix time */
	public ?int $untilDate = null;
}
